@@ -74,7 +74,10 @@ class R3sponse(object):
 	# parameter functions.
 	def get_request_parameter(self, request, identifier):
 		response = self.default_response()
-		variable = request.GET.get(identifier)
+		if request.POST
+			variable = request.POST.get(identifier)
+		else:
+			variable = request.GET.get(identifier)
 		if variable in ["", None]:
 			return variable, self.error_response(f"Define parameter: [{identifier}].")
 		return variable, self.success_response(f"Succesfully retrieved request parameter [{identifier}].")
@@ -139,7 +142,7 @@ class R3sponse(object):
 		else: 
 			msg = message
 		if log_level >= self.log_level:
-			print(color.fill(msg))
+			print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
 		if save: 
 			self.__log_to_file__(msg)
 		elif save_errors and _error_:
@@ -183,7 +186,7 @@ class R3sponse(object):
 		
 		# check file size.
 		size = Formats.FilePath(self.log_file).size(mode="mb", type="integer")
-		if int(size) >= 100: self.reset_logs()
+		if int(size.replace(" MB", "")) >= 100: self.reset_logs()
 
 		# return response.
 		return response
